"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const model = require("./model");
const data = require("./data");
const path = require("path");
const sequelize_typescript_1 = require("sequelize-typescript");
/**
 * @class
 * @classdesc 本地数据仓库
 */
class Store {
    static init(config) {
        if (!this.sequelize) {
            const modelPath = path.join(path.dirname(__filename), '/model');
            config.modelPaths = [modelPath];
            this.sequelize = new sequelize_typescript_1.Sequelize(config);
        }
    }
    static close() {
        if (this && this.sequelize) {
            this.sequelize.close();
        }
    }
    static buildTable() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.sequelize.sync({ force: true });
            yield Store.model.Sector.bulkCreate(Store.data.SectorList);
            yield Store.model.Exchange.bulkCreate(Store.data.ExchangeList);
            yield Store.model.Market.bulkCreate(Store.data.MarketList);
        });
    }
}
Store.model = model;
Store.data = data;
exports.Store = Store;
